@@ -10,6 +10,46 @@ try:
 except ImportError:
     from .compat.xact import xact as atomic
 
+# TODO consider subresources instead of prefetch_related()
+#   ie: manytomany: [
+#       '/api/v1/many/1/',
+#       '/api/v1/many/2/',
+#       '/api/v1/many/3/',
+#   ]
+#   vs
+#   manytomany: '/api/v1/resource/1/many/'
+#
+# in a lot of ways its much better because the server side doesn't need to
+# prefetch_related() needlessly and the client gets an easy uri to fetch all
+# the related models (which is difficult and the reason for `manytomany_id`
+# so the client can batch the entire request into a single set/ request)
+#
+# we could make this work with "options", you have a decision to make:
+#   - inline related resources (cant be done with flag a the moment)
+#   - current behavior of prefetch_related() and resource uris to related
+#   - subresource behavior described above
+#
+# XXX both methods have pros and cons
+#   current:
+#       pros:
+#           - client side caching can help resolve shared manytomany objects
+#       cons:
+#           - some oob knowledge must be used with the manytomany_id field
+#             to construct a url vs using the resource uris in the manytomany
+#             field (on the other hand, you could issue a request for each
+#             uri but that's wasteful/slow)
+#
+#   subresource:
+#       pros:
+#           - for a single object, it's trivial (and HATEOAS) to request
+#             a batch of objects that are related
+#       cons:
+#           - if you have many objects, how do you construct a single request
+#             for all related resources... its non-trivial
+#             (does object and related get merged on the server or client?
+#             it may only be possible on the server...)
+#
+# regardless, at this point, both methods are trivial to implement...
 class DjangoModelResource(object):
     '''
     Expose a Django Model as a RESTful resource.  Default implementation
@@ -34,6 +74,7 @@ class DjangoModelResource(object):
         excludes        list/tuple of field names to exclude from
                         serialize/deserialize
         fields          list/tuple of field names to serialize/deserialize
+        query_options   passed directly as opts to Query
         use_location    instead of returning a serialized payload on POST/PUT,
                         use a Location header to point to where you may get
                         the representation (default: False)
@@ -300,7 +341,7 @@ class DjangoModelResource(object):
 
         '''
         if not isinstance(query, self.Query):
-            query = self.Query(query)
+            query = self.make_query(query)
 
         try:
             qs, meta = query.apply(self.get_query_set(request))
@@ -352,7 +393,7 @@ class DjangoModelResource(object):
         isn't found or multiple are found when only one was expected.
         '''
         if query and not isinstance(query, self.Query):
-            query = self.Query(query)
+            query = self.make_query(query)
 
         qs = self.get_query_set(request)
         meta = None
@@ -451,6 +492,9 @@ class DjangoModelResource(object):
 
         self.expected_pk = self.expected[self.pk_name]
 
+    def make_query(self, query):
+        return self.Query(query, opts=getattr(self, 'query_options', None))
+
     def make_related_validator(self, field, expected, many=False):
         def related_validator(value, expect):
             resource = self.related_lookup(field)
@@ -549,7 +593,7 @@ class DjangoModelResource(object):
     def reverse_single(self, id):
         '''reverse_single(instance.pk) -> '/resource/1/'
 
-        Shortcut for creating a resource_uri.
+        Shortcut for creating a _uri.
         '''
         return self.reverse('single', args=(id,))
 
@@ -705,7 +749,7 @@ class DjangoModelResource(object):
                 else:
                     data[field.name] = getattr(instance, field.name)
 
-        data['resource_uri'] = self.reverse_single(instance.pk)
+        data['_uri'] = self.reverse_single(instance.pk)
 
         return data
 
@@ -935,7 +979,8 @@ class DjangoModelResource(object):
         query, data = self.api.deserialize(request)
 
         # dont modify only part of the query, modify the whole thing
-        query = self.Query(query).without('defer', 'limit', 'offset', 'only')
+        query = self.make_query(query) \
+            .without('defer', 'limit', 'offset', 'only')
 
         with atomic():
             instances, meta = self.fetch_list(request, query)
